Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(687)

Unified Diff: runtime/vm/object.h

Issue 23465004: More cleanup related to malformed and malbounded types. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/object.h
===================================================================
--- runtime/vm/object.h (revision 26669)
+++ runtime/vm/object.h (working copy)
@@ -817,24 +817,24 @@
bool IsSubtypeOf(const AbstractTypeArguments& type_arguments,
const Class& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const {
+ Error* bound_error) const {
return TypeTest(kIsSubtypeOf,
type_arguments,
other,
other_type_arguments,
- malformed_error);
+ bound_error);
}
// Check the 'more specific' relationship.
bool IsMoreSpecificThan(const AbstractTypeArguments& type_arguments,
const Class& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const {
+ Error* bound_error) const {
return TypeTest(kIsMoreSpecificThan,
type_arguments,
other,
other_type_arguments,
- malformed_error);
+ bound_error);
}
// Check if this is the top level class.
@@ -1067,7 +1067,7 @@
const AbstractTypeArguments& type_arguments,
const Class& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
FINAL_HEAP_OBJECT_IMPLEMENTATION(Class, Object);
friend class AbstractType;
@@ -1121,10 +1121,10 @@
// not refer to type parameters. Otherwise, return a new type argument vector
// where each reference to a type parameter is replaced with the corresponding
// type of the instantiator type argument vector.
// If malformed_error is not NULL, it may be set to reflect a bound error.
virtual RawAbstractTypeArguments* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
// Do not canonicalize InstantiatedTypeArguments or NULL objects
virtual RawAbstractTypeArguments* Canonicalize() const { return this->raw(); }
@@ -1157,16 +1157,16 @@
// Check the subtype relationship, considering only a prefix of length 'len'.
bool IsSubtypeOf(const AbstractTypeArguments& other,
intptr_t len,
- Error* malformed_error) const {
- return TypeTest(kIsSubtypeOf, other, len, malformed_error);
+ Error* bound_error) const {
+ return TypeTest(kIsSubtypeOf, other, len, bound_error);
}
// Check the 'more specific' relationship, considering only a prefix of
// length 'len'.
bool IsMoreSpecificThan(const AbstractTypeArguments& other,
intptr_t len,
- Error* malformed_error) const {
- return TypeTest(kIsMoreSpecificThan, other, len, malformed_error);
+ Error* bound_error) const {
+ return TypeTest(kIsMoreSpecificThan, other, len, bound_error);
}
bool Equals(const AbstractTypeArguments& other) const;
@@ -1196,7 +1196,7 @@
bool TypeTest(TypeTestKind test_kind,
const AbstractTypeArguments& other,
intptr_t len,
- Error* malformed_error) const;
+ Error* bound_error) const;
// Return the internal or public name of a subvector of this type argument
// vector, e.g. "<T, dynamic, List<T>, int>".
@@ -1231,7 +1231,7 @@
virtual RawAbstractTypeArguments* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
static const intptr_t kBytesPerElement = kWordSize;
static const intptr_t kMaxElements = kSmiMax / kBytesPerElement;
@@ -1677,19 +1677,19 @@
// parameters of the other function in order for this function to override the
// other function.
bool HasCompatibleParametersWith(const Function& other,
- Error* malformed_error) const;
+ Error* bound_error) const;
// Returns true if the type of this function is a subtype of the type of
// the other function.
bool IsSubtypeOf(const AbstractTypeArguments& type_arguments,
const Function& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const {
+ Error* bound_error) const {
return TypeTest(kIsSubtypeOf,
type_arguments,
other,
other_type_arguments,
- malformed_error);
+ bound_error);
}
// Returns true if the type of this function is more specific than the type of
@@ -1697,12 +1697,12 @@
bool IsMoreSpecificThan(const AbstractTypeArguments& type_arguments,
const Function& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const {
+ Error* bound_error) const {
return TypeTest(kIsMoreSpecificThan,
type_arguments,
other,
other_type_arguments,
- malformed_error);
+ bound_error);
}
// Returns true if this function represents an explicit getter function.
@@ -1849,7 +1849,7 @@
const AbstractTypeArguments& type_arguments,
const Function& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
// Checks the type of the formal parameter at the given position for
// subtyping or 'more specific' relationship between the type of this function
@@ -1860,7 +1860,7 @@
const AbstractTypeArguments& type_arguments,
const Function& other,
const AbstractTypeArguments& other_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
FINAL_HEAP_OBJECT_IMPLEMENTATION(Function, Object);
friend class Class;
@@ -3706,7 +3706,7 @@
// Check if the type of this instance is a subtype of the given type.
bool IsInstanceOf(const AbstractType& type,
const AbstractTypeArguments& type_instantiator,
- Error* malformed_error) const;
+ Error* bound_error) const;
bool IsValidNativeIndex(int index) const {
return ((index >= 0) && (index < clazz()->ptr()->num_native_fields_));
@@ -3781,10 +3781,10 @@
// Instantiate this type using the given type argument vector.
// Return a new type, or return 'this' if it is already instantiated.
// If malformed_error is not NULL, it may be set to reflect a bound error.
virtual RawAbstractType* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
virtual RawInstance* CheckAndCanonicalize(const char** error_str) const {
return Canonicalize();
@@ -3853,21 +3853,21 @@
bool IsFunctionType() const;
// Check the subtype relationship.
- bool IsSubtypeOf(const AbstractType& other, Error* malformed_error) const {
- return TypeTest(kIsSubtypeOf, other, malformed_error);
+ bool IsSubtypeOf(const AbstractType& other, Error* bound_error) const {
+ return TypeTest(kIsSubtypeOf, other, bound_error);
}
// Check the 'more specific' relationship.
bool IsMoreSpecificThan(const AbstractType& other,
- Error* malformed_error) const {
- return TypeTest(kIsMoreSpecificThan, other, malformed_error);
+ Error* bound_error) const {
+ return TypeTest(kIsMoreSpecificThan, other, bound_error);
}
private:
// Check the subtype or 'more specific' relationship.
bool TypeTest(TypeTestKind test_kind,
const AbstractType& other,
- Error* malformed_error) const;
+ Error* bound_error) const;
// Return the internal or public name of this type, including the names of its
// type arguments, if any.
@@ -4027,16 +4027,16 @@
RawAbstractType* bound() const { return raw_ptr()->bound_; }
void set_bound(const AbstractType& value) const;
// Returns true if bounded_type is below upper_bound, otherwise return false
- // and set malformed_error if not NULL.
+ // and set bound_error if not NULL.
bool CheckBound(const AbstractType& bounded_type,
const AbstractType& upper_bound,
- Error* malformed_error) const;
+ Error* bound_error) const;
virtual intptr_t token_pos() const { return raw_ptr()->token_pos_; }
virtual bool IsInstantiated() const { return false; }
virtual bool Equals(const Instance& other) const;
virtual RawAbstractType* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
virtual RawAbstractType* Canonicalize() const { return raw(); }
virtual intptr_t Hash() const;
@@ -4108,7 +4108,7 @@
virtual bool Equals(const Instance& other) const;
virtual RawAbstractType* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
- Error* malformed_error) const;
+ Error* bound_error) const;
virtual RawAbstractType* Canonicalize() const { return raw(); }
virtual intptr_t Hash() const;
@@ -1121,10 +1121,10 @@
// where each reference to a type parameter is replaced with the corresponding
// type of the instantiator type argument vector.
- // If malformed_error is not NULL, it may be set to reflect a bound error.
+ // If bound_error is not NULL, it may be set to reflect a bound error.
virtual RawAbstractTypeArguments* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,
@@ -3781,10 +3781,10 @@
// Instantiate this type using the given type argument vector.
// Return a new type, or return 'this' if it is already instantiated.
- // If malformed_error is not NULL, it may be set to reflect a bound error.
+ // If bound_error is not NULL, it may be set to reflect a bound error.
virtual RawAbstractType* InstantiateFrom(
const AbstractTypeArguments& instantiator_type_arguments,

Powered by Google App Engine
This is Rietveld 408576698